summaryrefslogtreecommitdiffstats
path: root/v3po/data-api
diff options
context:
space:
mode:
authorMaros Marsalek <mmarsale@cisco.com>2016-04-12 10:13:25 +0200
committerMaros Marsalek <mmarsale@cisco.com>2016-04-12 10:13:25 +0200
commitabd7814ef36ed9135c6e80b79ece76238d50a39c (patch)
tree5bc2762890fde439c7896fcf39a70841897968f5 /v3po/data-api
parent5970b9ec4f014869118026001e933c9847da2509 (diff)
HONEYCOMB-8: Remove references to VPP from data layer
Change-Id: Ia8ceb1f6e16c5148514ee2add55ff78533d8fe1e Signed-off-by: Marek Gradzki <mgradzki@cisco.com> Signed-off-by: Maros Marsalek <mmarsale@cisco.com>
Diffstat (limited to 'v3po/data-api')
-rw-r--r--v3po/data-api/pom.xml2
-rw-r--r--v3po/data-api/src/main/java/io/fd/honeycomb/v3po/data/DataTreeSnapshot.java (renamed from v3po/data-api/src/main/java/io/fd/honeycomb/v3po/data/VppDataTreeSnapshot.java)6
-rw-r--r--v3po/data-api/src/main/java/io/fd/honeycomb/v3po/data/ModifiableDataTree.java (renamed from v3po/data-api/src/main/java/io/fd/honeycomb/v3po/data/VppDataTree.java)16
-rw-r--r--v3po/data-api/src/main/java/io/fd/honeycomb/v3po/data/ReadableDataTree.java (renamed from v3po/data-api/src/main/java/io/fd/honeycomb/v3po/data/ReadableVppDataTree.java)6
4 files changed, 15 insertions, 15 deletions
diff --git a/v3po/data-api/pom.xml b/v3po/data-api/pom.xml
index 88be38d9f..60073734d 100644
--- a/v3po/data-api/pom.xml
+++ b/v3po/data-api/pom.xml
@@ -32,7 +32,7 @@
<dependency>
<groupId>org.opendaylight.controller</groupId>
<artifactId>sal-common-api</artifactId>
- <version>1.3.0-Beryllium</version>
+ <version>1.3.0-Beryllium</version> <!-- FIXME use dependency management -->
</dependency>
</dependencies>
diff --git a/v3po/data-api/src/main/java/io/fd/honeycomb/v3po/data/VppDataTreeSnapshot.java b/v3po/data-api/src/main/java/io/fd/honeycomb/v3po/data/DataTreeSnapshot.java
index 665a2e0ae..cae459299 100644
--- a/v3po/data-api/src/main/java/io/fd/honeycomb/v3po/data/VppDataTreeSnapshot.java
+++ b/v3po/data-api/src/main/java/io/fd/honeycomb/v3po/data/DataTreeSnapshot.java
@@ -20,13 +20,13 @@ import com.google.common.annotations.Beta;
import org.opendaylight.yangtools.yang.data.api.schema.tree.DataTreeModification;
/**
- * Read-only snapshot of a {@link ReadableVppDataTree}.
+ * Read-only snapshot of a {@link ReadableDataTree}.
*/
@Beta
-public interface VppDataTreeSnapshot extends ReadableVppDataTree {
+public interface DataTreeSnapshot extends ReadableDataTree {
/**
- * Creates a new VPP data tree modification.
+ * Creates a new data tree modification.
*
* @return A new data tree modification
*/
diff --git a/v3po/data-api/src/main/java/io/fd/honeycomb/v3po/data/ReadableVppDataTree.java b/v3po/data-api/src/main/java/io/fd/honeycomb/v3po/data/ReadableDataTree.java
index 22a52aa41..1cb8f806d 100644
--- a/v3po/data-api/src/main/java/io/fd/honeycomb/v3po/data/ReadableVppDataTree.java
+++ b/v3po/data-api/src/main/java/io/fd/honeycomb/v3po/data/ReadableDataTree.java
@@ -25,12 +25,12 @@ import org.opendaylight.yangtools.yang.data.api.YangInstanceIdentifier;
import org.opendaylight.yangtools.yang.data.api.schema.NormalizedNode;
/**
- * Facade over VPP data tree that allows reading tree nodes.
+ * Facade over data tree that allows reading tree nodes.
*/
@Beta
-public interface ReadableVppDataTree {
+public interface ReadableDataTree {
/**
- * Reads a particular node from the VPP data tree.
+ * Reads a particular node from the data tree.
*
* @param path Path of the node
* @return a CheckFuture containing the result of the read.
diff --git a/v3po/data-api/src/main/java/io/fd/honeycomb/v3po/data/VppDataTree.java b/v3po/data-api/src/main/java/io/fd/honeycomb/v3po/data/ModifiableDataTree.java
index dffd22d3a..8b21ddf24 100644
--- a/v3po/data-api/src/main/java/io/fd/honeycomb/v3po/data/VppDataTree.java
+++ b/v3po/data-api/src/main/java/io/fd/honeycomb/v3po/data/ModifiableDataTree.java
@@ -22,23 +22,23 @@ import org.opendaylight.yangtools.yang.data.api.schema.tree.DataTreeModification
import org.opendaylight.yangtools.yang.data.api.schema.tree.DataValidationFailedException;
/**
- * Facade over VPP data tree that allows tree modification.
+ * Facade over data tree that allows tree modification.
*/
@Beta
-public interface VppDataTree {
+public interface ModifiableDataTree {
/**
- * Commits modification to VPP data tree.
+ * Alters data tree using supplied modification.
*
- * @param modification VPP data tree modification
+ * @param modification data tree modification
* @throws DataValidationFailedException if modification data is not valid
- * @throws TranslationException if commit failed while updating VPP state
+ * @throws TranslationException if failed while updating data tree state
*/
- void commit(final DataTreeModification modification) throws DataValidationFailedException, TranslationException;
+ void modify(final DataTreeModification modification) throws DataValidationFailedException, TranslationException;
/**
* Creates read-only snapshot of a VppDataTree.
*
* @return Data tree snapshot.
*/
- VppDataTreeSnapshot takeSnapshot();
+ DataTreeSnapshot takeSnapshot();
}
@@ -22,23 +22,23 @@ import org.opendaylight.yangtools.yang.data.api.schema.tree.DataTreeModification
/**
- * Creates read-only snapshot of a VppDataTree.
+ * Creates read-only snapshot of a ModifiableDataTree.
*
* @return Data tree snapshot.